@@ -1,4 +1,4 @@
-# Gufw 17.04.1 - http://gufw.org
+# Gufw 17.10.0 - http://gufw.org
 # Copyright (C) 2008-2016 Marcos Alvarez Costales https://launchpad.net/~costales
 #
 # Gufw is free software; you can redistribute it and/or modify
@@ -458,16 +458,14 @@ class Backend():
         return result # cmd | ufw result
     
     def get_net_interfaces(self):
-        cmd_ifaces = ['netstat', '-i']
+        cmd_ifaces = ['ls', '/sys/class/net']
         cmd = self._run_cmd(cmd_ifaces)
         ifaces = cmd.split('\n')
         
-        index = 0
         result = []
         for iface in ifaces:
-            index = index + 1
-            if index > 2 and iface:
-                result.append(iface.split(' ')[0])
+            if iface:
+                result.append(iface)
         
         return result
     
