@@ -1,4 +1,4 @@
-# Gufw 17.04.1 - http://gufw.org
+# Gufw 17.10.0 - http://gufw.org
 # Copyright (C) 2008-2016 Marcos Alvarez Costales https://launchpad.net/~costales
 #
 # Gufw is free software; you can redistribute it and/or modify
@@ -169,6 +169,9 @@ class Gufw:
         self.txt_tag_gray   = self.log_txt.create_tag('colored_gray',   foreground=self.GRAY)
         self.txt_tag_black  = self.log_txt.create_tag('colored_black',  foreground=self.BLACK)
         
+        self.btn_report_pause = self.builder.get_object('btnReportPause')
+        self.btn_report_play  = self.builder.get_object('btnReportPlay')
+        
         # Stack init
         stack = Gtk.Stack()
         stack.set_transition_type(Gtk.StackTransitionType.SLIDE_LEFT_RIGHT)
@@ -289,6 +292,8 @@ class Gufw:
         
         if self.fw.get_status():
             self.print_rules(self.fw.get_rules())
+        
+        self.btn_report_play.hide()
 
     # Disable the context menu
     def context_menu_cb(webview, context_menu, event, hit_test_result, error):
@@ -517,6 +522,16 @@ class Gufw:
         self.winadd.set_add_from_report(protocol, port, address, app)
         self.winadd.show_win()        
     
+    def on_btnReportPause_clicked(self, widget, data=None):
+        self.btn_report_pause.hide()
+        self.btn_report_play.show()
+        self.listening.set_pause(True)
+    
+    def on_btnReportPlay_clicked(self, widget, data=None):
+        self.btn_report_pause.show()
+        self.btn_report_play.hide()
+        self.listening.set_pause(False)
+    
     def on_switchStatus_active_notify(self, widget, data=None):
         self.fw.set_status(self.switchStatus.get_active())
         self.print_rules(self.fw.get_rules())
