@@ -1,4 +1,4 @@
-# Gufw 17.04.1 - http://gufw.org
+# Gufw 17.10.0 - http://gufw.org
 # Copyright (C) 2008-2016 Marcos Alvarez Costales https://launchpad.net/~costales
 #
 # Gufw is free software; you can redistribute it and/or modify
@@ -30,6 +30,7 @@ class ListeningReport():
         self.gufw = gufw
         self.previous_report = []
         self.running_listening = True
+        self.paused_listening = False
         
         self._show_report()
         
@@ -55,7 +56,12 @@ class ListeningReport():
     def stopping(self):
         self.running_listening = False
     
+    def set_pause(self, value):
+        self.paused_listening = value
+    
     def _view_report(self, report, previous_report):
+        if self.paused_listening:
+            return
         # Selected?
         protocol = port = address = app = ''
         (model, rows) = self.gufw.tv_report.get_selection().get_selected_rows()
